import bs4
from pprint import pprint


def parse(gpage):

    def parse_snippet(snippet):
        title = snippet.h3.a.contents[0]
        content = ''.join(snippet.find('span', class_='st').strings)
        return {
            'title': title,
            'content': content
        }

    soup = bs4.BeautifulSoup(gpage, 'html.parser')
    snippets = soup.find_all('div', class_='rc')
    return [parse_snippet(s) for s in snippets]


def filt_email(snippets):

    def efilter(snippet):
        import re
        emails = []
        rough_pattern = re.compile(
            '[a-z0-9-\._]+(@| at | \[at\] |\[at\]| (at) |(at)| @ )(([a-z0-9\-]+)(\.| dot | \. | \[dot\] ))+([a-z]+)')
        rough_match = rough_pattern.finditer(snippet['content'])
        for rm in rough_match:
            pattern = re.compile(
                '(([a-z0-9-_]+)(\.| dot | \. )?)+(@| at | \[at\] |\[at\]| (at) |(at)| @ )(([a-z0-9\-]+)(\.| dot | \. | \[dot\] ))+([a-z]+)')
            match = pattern.finditer(rm.group())
            for m in match:
                emails.append(m.group().replace(' dot ', '.').replace(
                    ' at ', '@').replace('[at]', '@').replace('(at)', '@').replace(' ', ''))

        snippet['emails'] = emails
        return snippet

    snippets = [efilter(s) for s in snippets]
    snippets = [s for s in snippets if s['emails']]
    return snippets


if __name__ == '__main__':
    with open('test.html', encoding='utf-8') as f:
        gpage = f.read()
    items = parse(gpage)
    pprint(items)
    print(filt_email(items))



# encoding: utf-8
import requests


class Proxy:
    PROXIES = []

    @classmethod
    def add_proxies(cls):
        url = 'http://erwx.daili666.com/ip/?tid=558045424788230&num=20&foreign=only'
        proxies = requests.get(url).text.splitlines()
        cls.PROXIES = [p.strip() for p in proxies]

    @classmethod
    def pop_proxy(cls):
        if cls.PROXIES:
            cls.PROXIES = cls.PROXIES[1:]

    @classmethod
    def choose_proxy(cls):
        if not cls.PROXIES:
            cls.add_proxies()
        return cls.PROXIES[0]


def download_page(url, useproxy=True, verbose=True, maxtry=2, timeout=5):

    def retry():
        if verbose:
            print('[FAIL-{}] {} -> {}'.format(maxtry, proxy_ip, url))
        return download_page(url, useproxy, verbose, maxtry - 1, timeout)

    if maxtry <= 0:
        return None
    try:
        proxy_ip = 'localhost'
        if useproxy:
            proxy_ip = Proxy.choose_proxy()
        header = {
            'user-agent': 'Mozilla/5.0 (Windows NT 6.1 WOW64 rv:23.0) Gecko/20130406 Firefox/23.0'
        }
        proxy = {
            'http': proxy_ip
        }
        content = requests.get(url, proxies=proxy, headers=header).text
        if verbose:
            print('[OK] {} -> {}'.format(proxy_ip, url))
        return content

    except Exception as e:
        if useproxy:
            Proxy.pop_proxy()
        return retry()


def search(query, useproxy=True, verbose=True, maxtry=5, timeout=5):
    query = query.replace(' ', '+')
    url = 'https://www.google.com/search?hl=en&safe=off&q={}'.format(query)
    return download_page(url, useproxy, verbose, maxtry, timeout)


if __name__ == '__main__':
    with open('test.html', 'w', encoding='utf-8') as wf:
        page = search('jie tang')
        wf.write(page)
        # page = requests.get('http://baidu.com')



# encoding: UTF-8
from setuptools import setup
"""
打包的用的setup必须引入
"""

VERSION = '1.3'

with open('README.md') as f:
    long_description = f.read()

setup(
    name='gopage',  # 文件名
    version=VERSION,  # 版本(每次更新上传Pypi需要修改)
    description="Py3 version",
    long_description=long_description,  # 放README.md文件,方便在Pypi页展示
    classifiers=[],
    keywords='python google crawler',  # 关键字
    author='xgeric',  # 用户名
    author_email='guxt1994@gmail.com',  # 邮箱
    url='https://xgeric.github.io',  # github上的地址,别的地址也可以
    license='MIT',  # 遵循的协议
    packages=['gopage'],  # 发布的包名
    include_package_data=True,
    zip_safe=True,
    install_requires=[
        'bs4',
        'requests'
    ],  # 满足的依赖
)
